pub enum QueuedRequestKind {
Event {
content: SerializableEventContent,
},
MediaUpload {
content_type: String,
cache_key: MediaRequestParameters,
thumbnail_source: Option<MediaSource>,
related_to: OwnedTransactionId,
accumulated: Vec<AccumulatedSentMediaInfo>,
},
Redaction {
redacts: OwnedEventId,
reason: Option<String>,
},
}Expand description
The kind of a send queue request.
Variants
Event
An event to be sent via the send queue.
Fields
content: SerializableEventContentThe content of the message-like event we’d like to send.
MediaUpload
Content to upload on the media server.
The bytes must be stored in the media cache, and are identified by the cache key.
Fields
content_type: StringContent type of the media to be uploaded.
Stored as a String because Mime which we’d really want to use
here, is not serializable. Oh well.
cache_key: MediaRequestParametersThe cache key used to retrieve the media’s bytes in the event cache store.
thumbnail_source: Option<MediaSource>An optional media source for a thumbnail already uploaded.
To which media event transaction does this upload relate?
accumulated: Vec<AccumulatedSentMediaInfo>unstable-msc4274 only.Accumulated list of infos for previously uploaded files and thumbnails if used during a gallery transaction. Otherwise empty.
Redaction
A redaction of another event to send.
Fields
redacts: OwnedEventIdThe ID of the event to redact.