pub struct AvatarCache { /* private fields */ }Expand description
A cache for keeping track of avatar changes in sync responses.
Implementations
Sourceimpl AvatarCache
impl AvatarCache
Sourcepub fn new(store: SaveLockedStateStore) -> AvatarCache
pub fn new(store: SaveLockedStateStore) -> AvatarCache
Creates a new AvatarCache.
Sourcepub async fn handle_event(
&mut self,
state_changes: &StateChanges,
room_id: &RoomId,
member_event: &SyncStateEvent<RoomMemberEventContent>,
) -> Result<(), StoreError>
pub async fn handle_event( &mut self, state_changes: &StateChanges, room_id: &RoomId, member_event: &SyncStateEvent<RoomMemberEventContent>, ) -> Result<(), StoreError>
Processes the room member event and checks if there was any change in the avatar URL for the room member.
Sourcepub fn remove_changes(
&mut self,
room_id: &RoomId,
) -> Option<BTreeMap<OwnedUserId, Option<OwnedMxcUri>>>
pub fn remove_changes( &mut self, room_id: &RoomId, ) -> Option<BTreeMap<OwnedUserId, Option<OwnedMxcUri>>>
Removes and returns the avatar changes associated with the RoomId,
if any.