IntoStateStore

Trait IntoStateStore 

pub trait IntoStateStore { }
A type that can be type-erased into Arc<dyn StateStore>.

This trait is not meant to be implemented directly outside matrix-sdk-crypto, but it is automatically implemented for everything that implements StateStore.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> IntoStateStore for T
where T: StateStore + 'static,