StateStoreIntegrationTests

Trait StateStoreIntegrationTests 

pub trait StateStoreIntegrationTests {
Show 29 methods // Required methods async fn populate(&self) -> Result<(), TestError>; async fn test_topic_redaction(&self) -> Result<(), TestError>; async fn test_populate_store(&self) -> Result<(), TestError>; async fn test_member_saving(&self) -> Result<(), TestError>; async fn test_filter_saving(&self) -> Result<(), TestError>; async fn test_user_avatar_url_saving(&self) -> Result<(), TestError>; async fn test_sync_token_saving(&self) -> Result<(), TestError>; async fn test_utd_hook_manager_data_saving(&self) -> Result<(), TestError>; async fn test_one_time_key_already_uploaded_data_saving( &self, ) -> Result<(), TestError>; async fn test_stripped_member_saving(&self) -> Result<(), TestError>; async fn test_power_level_saving(&self) -> Result<(), TestError>; async fn test_receipts_saving(&self) -> Result<(), TestError>; async fn test_custom_storage(&self) -> Result<(), TestError>; async fn test_stripped_non_stripped(&self) -> Result<(), TestError>; async fn test_room_removal(&self) -> Result<(), TestError>; async fn test_profile_removal(&self) -> Result<(), TestError>; async fn test_presence_saving(&self) -> Result<(), TestError>; async fn test_display_names_saving(&self) -> Result<(), TestError>; async fn test_send_queue(&self) -> Result<(), TestError>; async fn test_send_queue_priority(&self) -> Result<(), TestError>; async fn test_send_queue_dependents(&self) -> Result<(), TestError>; async fn test_update_send_queue_dependent(&self) -> Result<(), TestError>; async fn test_supported_versions_saving(&self) -> Result<(), TestError>; async fn test_well_known_saving(&self) -> Result<(), TestError>; async fn test_get_room_infos(&self) -> Result<(), TestError>; async fn test_thread_subscriptions(&self) -> Result<(), TestError>; async fn test_thread_subscriptions_bulk_upsert( &self, ) -> Result<(), TestError>; async fn test_global_profiles_saving(&self) -> Result<(), TestError>; async fn test_global_profiles_bulk_loading(&self) -> Result<(), TestError>;
}
StateStore integration tests.

This trait is not meant to be used directly, but will be used with the statestore_integration_tests! macro.

Required Methods

async fn populate(&self) -> Result<(), TestError>

Populate the given StateStore.

async fn test_topic_redaction(&self) -> Result<(), TestError>

Test room topic redaction.

async fn test_populate_store(&self) -> Result<(), TestError>

Test populating the store.

async fn test_member_saving(&self) -> Result<(), TestError>

Test room member saving.

async fn test_filter_saving(&self) -> Result<(), TestError>

Test filter saving.

async fn test_user_avatar_url_saving(&self) -> Result<(), TestError>

Test saving a user avatar URL.

async fn test_sync_token_saving(&self) -> Result<(), TestError>

Test sync token saving.

async fn test_utd_hook_manager_data_saving(&self) -> Result<(), TestError>

Test UtdHookManagerData saving.

async fn test_one_time_key_already_uploaded_data_saving( &self, ) -> Result<(), TestError>

Test the saving of the OneTimeKeyAlreadyUploaded key/value data type.

async fn test_stripped_member_saving(&self) -> Result<(), TestError>

Test stripped room member saving.

async fn test_power_level_saving(&self) -> Result<(), TestError>

Test room power levels saving.

async fn test_receipts_saving(&self) -> Result<(), TestError>

Test user receipts saving.

async fn test_custom_storage(&self) -> Result<(), TestError>

Test custom storage.

async fn test_stripped_non_stripped(&self) -> Result<(), TestError>

Test stripped and non-stripped room member saving.

async fn test_room_removal(&self) -> Result<(), TestError>

Test room removal.

async fn test_profile_removal(&self) -> Result<(), TestError>

Test profile removal.

async fn test_presence_saving(&self) -> Result<(), TestError>

Test presence saving.

async fn test_display_names_saving(&self) -> Result<(), TestError>

Test display names saving.

async fn test_send_queue(&self) -> Result<(), TestError>

Test operations with the send queue.

async fn test_send_queue_priority(&self) -> Result<(), TestError>

Test priority of operations with the send queue.

async fn test_send_queue_dependents(&self) -> Result<(), TestError>

Test operations related to send queue dependents.

async fn test_update_send_queue_dependent(&self) -> Result<(), TestError>

Test an update to a send queue dependent request.

async fn test_supported_versions_saving(&self) -> Result<(), TestError>

Test saving/restoring the supported versions of the server.

async fn test_well_known_saving(&self) -> Result<(), TestError>

Test saving/restoring the well-known info of the server.

async fn test_get_room_infos(&self) -> Result<(), TestError>

Test fetching room infos based on RoomLoadSettings.

async fn test_thread_subscriptions(&self) -> Result<(), TestError>

Test loading thread subscriptions.

async fn test_thread_subscriptions_bulk_upsert(&self) -> Result<(), TestError>

Test thread subscriptions bulk upsert, including bumpstamp semantics.

async fn test_global_profiles_saving(&self) -> Result<(), TestError>

Test global profiles bulk saving and merging.

async fn test_global_profiles_bulk_loading(&self) -> Result<(), TestError>

Test loading global profiles for several users at once.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors